@@ -24,7 +24,7 @@
 #include <stdarg.h>
 #include "ass_types.h"
 
-#define LIBASS_VERSION 0x01702000
+#define LIBASS_VERSION 0x01704000
 
 #ifdef __cplusplus
 extern "C" {
@@ -62,9 +62,12 @@ extern "C" {
 typedef struct ass_image {
     int w, h;                   // Bitmap width/height
     int stride;                 // Bitmap stride
-    unsigned char *bitmap;      // 1bpp stride*h alpha buffer
+    unsigned char *bitmap;      // 1-byte-per-pixel alpha buffer
                                 // Note: the last row may not be padded to
                                 // bitmap stride!
+                                // The guaranteed allocated size is
+                                // `(stride * (h - 1)) + w`, and bytes past
+                                // the width in each line may be uninitialized.
     uint32_t color;             // Bitmap color and alpha, RGBA
                                 // For full VSFilter compatibility, the value
                                 // must be transformed as described in
@@ -154,7 +157,7 @@ typedef enum {
      */
     ASS_OVERRIDE_BIT_FONT_SIZE ASS_DEPRECATED_ENUM("replaced by ASS_OVERRIDE_BIT_SELECTIVE_FONT_SCALE") = 1 << 1,
     /**
-     * On dialogue events override: FontSize, Spacing, Blur, ScaleX, ScaleY
+     * On dialogue events override: FontSize, Spacing, ScaleX, ScaleY
      */
     ASS_OVERRIDE_BIT_FONT_SIZE_FIELDS = 1 << 2,
     /**
@@ -194,6 +197,10 @@ typedef enum {
      * On dialogue events override: Justify
      */
     ASS_OVERRIDE_BIT_JUSTIFY = 1 << 10,
+    /**
+     * On dialogue events override: Blur
+     */
+    ASS_OVERRIDE_BIT_BLUR = 1 << 11,
     // New enum values can be added here in new ABI-compatible library releases.
 } ASS_OverrideBits;
 
@@ -324,9 +331,14 @@ void ass_set_extract_fonts(ASS_Library *priv, int extract);
  *   ScaledBorderAndShadow=yes
  *
  * \param priv library handle
- * \param list NULL-terminated list of strings
+ * \param list NULL-terminated list of strings,
+ *             copied and never modified by libass
  */
+#ifdef __cplusplus
+void ass_set_style_overrides(ASS_Library *priv, const char *const *list);
+#else
 void ass_set_style_overrides(ASS_Library *priv, char **list);
+#endif
 
 /**
  * \brief Explicitly process style overrides for a track.
@@ -532,7 +544,7 @@ void ass_get_available_font_providers(ASS_Library *priv,
  * \param default_family fallback font family, or NULL
  * \param dfp which font provider to use (one of ASS_DefaultFontProvider). In
  * older libass version, this could be 0 or 1, where 1 enabled fontconfig.
- * Newer relases also accept 0 (ASS_FONTPROVIDER_NONE) and 1
+ * Newer releases also accept 0 (ASS_FONTPROVIDER_NONE) and 1
  * (ASS_FONTPROVIDER_AUTODETECT), which is almost backward-compatible.
  * If the requested fontprovider does not exist or fails to initialize, the
  * behavior is the same as when ASS_FONTPROVIDER_NONE was passed.
@@ -685,12 +697,12 @@ void ass_free_style(ASS_Track *track, int sid);
 void ass_free_event(ASS_Track *track, int eid);
 
 /**
- * \brief Parse a chunk of subtitle stream data.
+ * \brief Parse full lines of subtitle stream data.
  * \param track track
  * \param data string to parse
  * \param size length of data
  */
-void ass_process_data(ASS_Track *track, char *data, int size);
+void ass_process_data(ASS_Track *track, const char *data, int size);
 
 /**
  * \brief Parse Codec Private section of the subtitle stream, in Matroska
@@ -699,7 +711,7 @@ void ass_process_data(ASS_Track *track, char *data, int size);
  * \param data string to parse
  * \param size length of data
  */
-void ass_process_codec_private(ASS_Track *track, char *data, int size);
+void ass_process_codec_private(ASS_Track *track, const char *data, int size);
 
 /**
  * \brief Parse a chunk of subtitle stream data. A chunk contains exactly one
@@ -715,7 +727,7 @@ void ass_process_codec_private(ASS_Track *track, char *data, int size);
  * \param timecode starting time of the event (milliseconds)
  * \param duration duration of the event (milliseconds)
  */
-void ass_process_chunk(ASS_Track *track, char *data, int size,
+void ass_process_chunk(ASS_Track *track, const char *data, int size,
                        long long timecode, long long duration);
 
 /**
@@ -729,6 +741,24 @@ void ass_process_chunk(ASS_Track *track, char *data, int size,
  */
 void ass_set_check_readorder(ASS_Track *track, int check_readorder);
 
+/**
+ * \brief Prune events that preceed deadline.
+ * \param track track
+ * \param deadline cut-off timestamp in milliseconds.
+*/
+void ass_prune_events(ASS_Track *track, long long deadline);
+
+/**
+ * \brief Configure automatic pruning of events.
+ * \param track track
+ * \param delay delay from "now" (ass_render_frame) in milliseconds.
+ * After every render, events whose undisplay timestamp predate
+ * "now - delay" will be deleted. A delay of 0 prunes aggressively.
+ * Negative delays disable automatic pruning.
+ * Disabled by default (no removal of events from memory).
+ */
+void ass_configure_prune(ASS_Track *track, long long delay);
+
 /**
  * \brief Flush buffered events.
  * \param track track
@@ -747,8 +777,8 @@ void ass_flush_events(ASS_Track *track);
  * if both versions are valid and exist.
  * On all other systems there is no need for special considerations like that.
 */
-ASS_Track *ass_read_file(ASS_Library *library, char *fname,
-                         char *codepage);
+ASS_Track *ass_read_file(ASS_Library *library, const char *fname,
+                         const char *codepage);
 
 /**
  * \brief Read subtitles from memory.
@@ -759,7 +789,7 @@ ASS_Track *ass_read_file(ASS_Library *library, char *fname,
  * \return newly allocated track or NULL on failure
 */
 ASS_Track *ass_read_memory(ASS_Library *library, char *buf,
-                           size_t bufsize, char *codepage);
+                           size_t bufsize, const char *codepage);
 /**
  * \brief Read styles from file into already initialized track.
  * \param fname file name
@@ -771,7 +801,7 @@ ASS_Track *ass_read_memory(ASS_Library *library, char *buf,
  * if both versions are valid and exist.
  * On all other systems there is no need for special considerations like that.
  */
-int ass_read_styles(ASS_Track *track, char *fname, char *codepage);
+int ass_read_styles(ASS_Track *track, const char *fname, const char *codepage);
 
 /**
  * \brief Add a memory font.
@@ -802,6 +832,22 @@ void ass_clear_fonts(ASS_Library *library);
  */
 long long ass_step_sub(ASS_Track *track, long long now, int movement);
 
+/**
+ * \brief Allocates memory that can be safely freed by libass later.
+ * Use this to allocate buffers you'll use to manually modify ASS_Track events
+ * or related structures.
+ * \param size number of bytes to allocate
+ * \return pointer to the allocated buffer, or NULL on failure
+ */
+void *ass_malloc(size_t size);
+
+/**
+ * \brief Releases memory previously allocated within libass.
+ * Use this to free memory allocated using ass_malloc.
+ * \param ptr pointer to the buffer to release; passing NULL is a no-op
+ */
+void ass_free(void *ptr);
+
 #undef ASS_DEPRECATED
 #undef ASS_DEPRECATED_ENUM
 
